==> libertem-0.1.0rc2.tar.gz: libertem-0.1.0rc2/client/src/cluster/components/TCPConnectionForm.tsx <==

import { FormikProps, withFormik } from "formik";
import * as React from "react";
import { Button, Form } from "semantic-ui-react";
import { Omit } from "../../helpers/types";
import { ClusterTypes, ConnectRequestTCP } from "../../messages";

type FormValues = Omit<ConnectRequestTCP, "type">;

interface FormProps {
    onSubmit: (params: ConnectRequestTCP) => void,
}

type MergedProps = FormikProps<FormValues> & FormProps;

const TCPConnectionForm: React.SFC<MergedProps> = ({
    values,
    touched,
    errors,
    dirty,
    isSubmitting,
    handleChange,
    handleBlur,
    handleSubmit,
    handleReset,
}) => {
    return (
        <Form onSubmit={handleSubmit}>
            <Form.Field>
                <label htmlFor="isLocal">Is a local cluster:</label>
                <input type="checkbox" name="isLocal" checked={values.isLocal}
                    onChange={handleChange}
                    onBlur={handleBlur} />
                {errors.isLocal && touched.isLocal && errors.isLocal}
            </Form.Field>
            <Form.Field>
                <label htmlFor="address">Scheduler URI</label>
                <input type="text" name="address" value={values.address}
                    onChange={handleChange}
                    onBlur={handleBlur} />
                {errors.address && touched.address && errors.address}
            </Form.Field>
            <Button primary={true} type="submit" disabled={isSubmitting}>Connect</Button>
        </Form>
    )
}

export default withFormik<FormProps, FormValues>({
    mapPropsToValues: () => ({
        isLocal: true,
        address: "tcp://localhost:8786",
    }),
    handleSubmit: (values, formikBag) => {
        const { onSubmit } = formikBag.props;
        onSubmit({
            type: ClusterTypes.TCP,
            ...values
        });
    }
})(TCPConnectionForm);

==> libertem-0.7.1.tar.gz: libertem-0.7.1/client/src/cluster/components/TCPConnectionForm.tsx <==

import { FormikProps, withFormik } from "formik";
import * as React from "react";
import { Button, Form } from "semantic-ui-react";
import { ConfigState } from "../../config/reducers";
import { Omit } from "../../helpers/types";
import { ClusterTypes, ConnectRequestTCP } from "../../messages";

type FormValues = Omit<ConnectRequestTCP, "type">;

interface FormProps {
    onSubmit: (params: ConnectRequestTCP) => void,
    config: ConfigState,
}

type MergedProps = FormikProps<FormValues> & FormProps;

const TCPConnectionForm: React.SFC<MergedProps> = ({
    values,
    touched,
    errors,
    dirty,
    isSubmitting,
    handleChange,
    handleBlur,
    handleSubmit,
    handleReset,
}) => {
    return (
        <Form onSubmit={handleSubmit}>
            <Form.Field>
                <label htmlFor="address">Scheduler URI</label>
                <input type="text" name="address" value={values.address}
                    onChange={handleChange}
                    onBlur={handleBlur} />
                {errors.address && touched.address && errors.address}
            </Form.Field>
            <Button primary={true} type="submit" disabled={isSubmitting}>Connect</Button>
        </Form>
    )
}

export default withFormik<FormProps, FormValues>({
    mapPropsToValues: (ownProps: FormProps) => ({
        address: ownProps.config.lastConnection.address,
    }),
    handleSubmit: (values, formikBag) => {
        const { onSubmit } = formikBag.props;
        onSubmit({
            type: ClusterTypes.TCP,
            ...values
        });
    }
})(TCPConnectionForm);
